@@ -1,6 +1,6 @@
 package CPAN::Meta::Check;
 {
-  $CPAN::Meta::Check::VERSION = '0.002';
+  $CPAN::Meta::Check::VERSION = '0.003';
 }
 use strict;
 use warnings;
@@ -14,10 +14,10 @@ use CPAN::Meta::Requirements 2.120920;
 use Module::Metadata;
 
 sub _check_dep {
-	my ($reqs, $module) = @_;
+	my ($reqs, $module, $dirs) = @_;
 
 	my $version = $module eq 'perl' ? $] : do { 
-		my $metadata = Module::Metadata->new_from_module($module);
+		my $metadata = Module::Metadata->new_from_module($module, inc => $dirs);
 		return "Module '$module' is not installed" if not defined $metadata;
 		eval { $metadata->version };
 	};
@@ -27,8 +27,8 @@ sub _check_dep {
 }
 
 sub _check_conflict {
-	my ($reqs, $module) = @_;
-	my $metadata = Module::Metadata->new_from_module($module);
+	my ($reqs, $module, $dirs) = @_;
+	my $metadata = Module::Metadata->new_from_module($module, inc => $dirs);
 	return if not defined $metadata;
 	my $version = eval { $metadata->version };
 	return "Missing version info for module '$module'" if not $version;
@@ -52,26 +52,26 @@ sub requirements_for {
 }
 
 sub check_requirements {
-	my ($reqs, $type) = @_;
+	my ($reqs, $type, $dirs) = @_;
 
 	my %ret;
 	if ($type ne 'conflicts') {
 		for my $module ($reqs->required_modules) {
-			$ret{$module} = _check_dep($reqs, $module);
+			$ret{$module} = _check_dep($reqs, $module, $dirs);
 		}
 	}
 	else {
 		for my $module ($reqs->required_modules) {
-			$ret{$module} = _check_conflict($reqs, $module);
+			$ret{$module} = _check_conflict($reqs, $module, $dirs);
 		}
 	}
 	return \%ret;
 }
 
 sub verify_dependencies {
-	my ($meta, $phases, $type) = @_;
+	my ($meta, $phases, $type, $dirs) = @_;
 	my $reqs = requirements_for($meta, $phases, $type);
-	my $issues = check_requirements($reqs, $type);
+	my $issues = check_requirements($reqs, $type, $dirs);
 	return grep { defined } values %{ $issues };
 }
 
@@ -89,7 +89,7 @@ CPAN::Meta::Check - Verify requirements in a CPAN::Meta object
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -97,7 +97,7 @@ version 0.002
 
 =head1 DESCRIPTION
 
-This module verifies if modules are 
+This module verifies if requirements described in a CPAN::Meta object are present.
 
 =head1 FUNCTIONS
 
@@ -105,13 +105,23 @@ This module verifies if modules are
 
 This function checks if all dependencies in C<$reqs> (a L<CPAN::Meta::Requirements|CPAN::Meta::Requirements> object) are met, taking into account that 'conflicts' dependencies have to be checked in reverse. It returns a hash with the modules as values and any problems as keys, the value for a succesfully found module will be undef.
 
-=head2 verify_dependencies($meta, $phases, $types)
+=head2 verify_dependencies($meta, $phases, $types, $incdirs)
 
-Check all requirements in C<$meta> for phases C<$phases> and types C<$types>.
+Check all requirements in C<$meta> for phases C<$phases> and types C<$types>. Modules are searched for in C<@$incdirs>, defaulting to C<@INC>.
 
-=head2 requirements_for($meta, $phases, $types)
+=head2 requirements_for($meta, $phases, $types, incdirs)
 
-This function returns a unified L<CPAN::Meta::Requirements|CPAN::Meta::Requirements> object for all C<$type> requirements for C<$phases>. $Phases may be either one (scalar) value or an arrayref of valid values as defined by the L<CPAN::Meta spec|CPAN::Meta::Spec>. C<$type> must be a a relationship as defined by the same spec.
+This function returns a unified L<CPAN::Meta::Requirements|CPAN::Meta::Requirements> object for all C<$type> requirements for C<$phases>. $phases may be either one (scalar) value or an arrayref of valid values as defined by the L<CPAN::Meta spec|CPAN::Meta::Spec>. C<$type> must be a a relationship as defined by the same spec. Modules are searched for in C<@$incdirs>, defaulting to C<@INC>.
+
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<Test::CheckDeps|Test::CheckDeps>
+
+=item * L<CPAN::Meta|CPAN::Meta>
+
+=back
 
 =head1 AUTHOR
 
